@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO coverage description
-#' @return Object of \code{\link{R6Class}} for modelling an ISOCoverageDescription
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISOCoverageDescription
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'    #create coverage description
@@ -40,15 +40,20 @@
 #'    xml <- md$encode()
 #'    
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata 
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_MD_CoverageDescription}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mrc/1.0/mrc/#element_MD_CoverageDescription}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
 ISOCoverageDescription <- R6Class("ISOCoverageDescription",
-   inherit = ISOContentInformation,
+   inherit = ISOAbstractContentInformation,
    private = list(
      xmlElement = "MD_CoverageDescription",
-     xmlNamespacePrefix = "GMD"
+     xmlNamespacePrefix = list(
+       "19139" = "GMD",
+       "19115-3" = "MRC"
+     )
    ),
    public = list(
      
@@ -60,7 +65,7 @@ ISOCoverageDescription <- R6Class("ISOCoverageDescription",
      dimension = list(),
      
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      initialize = function(xml = NULL){
        super$initialize(xml = xml)
      },
@@ -104,4 +109,4 @@ ISOCoverageDescription <- R6Class("ISOCoverageDescription",
      }
      
    )                        
-)
\ No newline at end of file
+)
