@@ -4,14 +4,16 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO freeText
-#' @return Object of \code{\link{R6Class}} for modelling an ISO FreeText
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO FreeText
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'   ft <- ISOFreeText$new()
 #'   
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata
+#'  - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_PT_FreeText}
+#'  
+#'  - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/lan/1.0/lan/#element_PT_FreeText}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -19,14 +21,17 @@ ISOFreeText <- R6Class("ISOFreeText",
    inherit = ISOAbstractObject,
    private = list(
      xmlElement = "PT_FreeText",
-     xmlNamespacePrefix = "GMD"
+     xmlNamespacePrefix = list(
+        "19139" = "GMD",
+        "19115-3" = "LAN"
+     )
    ),
    public = list(
      #'@field textGroup textGroup [1..*]: ISOLocalisedCharacterString
      textGroup = list(),
      
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      initialize = function(xml = NULL){
        super$initialize(xml = xml)
      },
@@ -52,4 +57,4 @@ ISOFreeText <- R6Class("ISOFreeText",
      }
      
    )                        
-)
\ No newline at end of file
+)
