@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO coverage description
-#' @return Object of \code{\link{R6Class}} for modelling an ISOImageDescription
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISOImageDescription
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'    #create image description
@@ -54,7 +54,9 @@
 #'    xml <- md$encode()
 #'    
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata 
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_MD_ImageDescription}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mrc/1.0/mrc/#element_MD_ImageDescription}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -62,7 +64,10 @@ ISOImageDescription <- R6Class("ISOImageDescription",
   inherit = ISOCoverageDescription,
   private = list(
     xmlElement = "MD_ImageDescription",
-    xmlNamespacePrefix = "GMD"
+    xmlNamespacePrefix = list(
+      "19139" = "GMD",
+      "19115-3" = "MRC"
+    )
   ),
   public = list(
     #'@field illuminationElevationAngle illuminationElevationAngle [0..1]
@@ -91,7 +96,7 @@ ISOImageDescription <- R6Class("ISOImageDescription",
     lensDistortionInformationAvailability = NULL,
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     },
@@ -224,4 +229,4 @@ ISOImageDescription <- R6Class("ISOImageDescription",
     }
     
   )                        
-)
\ No newline at end of file
+)
