@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO imagery image description
-#' @return Object of \code{\link{R6Class}} for modelling an ISO imagery image description
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO imagery image description
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'    #create coverage description
@@ -47,7 +47,9 @@
 #'    xml <- md$encode()
 #' 
 #' @references 
-#'   ISO 19115-2:2009 - Geographic information -- Metadata Part 2: Extensions for imagery and gridded data
+#'   - 19139 \url{https://schemas.isotc211.org/19115/-2/gmi/1.0/gmi/#element_MI_CoverageDescription}
+#'   
+#'   - 19115-3 \url{https://schemas.isotc211.org/19115/-3/mrc/1.0/mrc/#element_MI_CoverageDescription}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #' 
@@ -55,14 +57,17 @@ ISOImageryCoverageDescription <- R6Class("ISOImageryCoverageDescription",
   inherit = ISOCoverageDescription,
   private = list(
     xmlElement = "MI_CoverageDescription",
-    xmlNamespacePrefix = "GMI"
+    xmlNamespacePrefix = list(
+      "19139" = "GMI",
+      "19115-3" = "MRC"
+    )
   ),
   public = list(
     #'@field rangeElementDescription rangeElementDescription [0..*] : ISOImageryRangeElementDescription
     rangeElementDescription = list(),
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     },
@@ -87,4 +92,4 @@ ISOImageryCoverageDescription <- R6Class("ISOImageryCoverageDescription",
       return(self$delListElement("rangeElementDescription", description))
     }
   )                        
-)
\ No newline at end of file
+)
