@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO imagery event
-#' @return Object of \code{\link{R6Class}} for modelling an ISO imagery event
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO imagery event
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'    md <- ISOImageryEvent$new()
@@ -18,7 +18,9 @@
 #'    xml <- md$encode()
 #' 
 #' @references 
-#'   ISO 19115-2:2009 - Geographic information -- Metadata Part 2: Extensions for imagery and gridded data
+#'   - 19139 \url{https://schemas.isotc211.org/19115/-2/gmi/1.0/gmi/#element_MI_Event}
+#'   
+#'   - 19115-3 \url{https://schemas.isotc211.org/19115/-3/mac/2.0/mac/#element_MI_Event}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #' 
@@ -26,7 +28,10 @@ ISOImageryEvent <- R6Class("ISOImageryEvent",
   inherit = ISOAbstractObject,
   private = list(
     xmlElement = "MI_Event",
-    xmlNamespacePrefix = "GMI"
+    xmlNamespacePrefix = list(
+      "19139" = "GMI",
+      "19115-3" = "MAC"
+    )
   ),
   public = list(
 
@@ -48,7 +53,7 @@ ISOImageryEvent <- R6Class("ISOImageryEvent",
     expectedObjective = list(),
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     },
@@ -166,4 +171,4 @@ ISOImageryEvent <- R6Class("ISOImageryEvent",
       return(self$delListElement("expectedObjective", objective))
     }
   )                        
-)
\ No newline at end of file
+)
