@@ -4,11 +4,13 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO imagery Georeferenceable
-#' @return Object of \code{\link{R6Class}} for modelling an ISO imagery Georeferenceable
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO imagery Georeferenceable
+#' @format \code{\link[R6]{R6Class}} object.
 #'
 #' @references 
-#'   ISO 19115-2:2009 - Geographic information -- Metadata -- Part 2: Extensions for imagery and gridded data
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19115/-2/gmi/1.0/gmi/#element_MI_Georeferenceable}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/msr/1.0/msr/#element_MI_Georeferenceable}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -16,7 +18,10 @@ ISOImageryGeoreferenceable <- R6Class("ISOImageryGeoreferenceable",
   inherit = ISOGeoreferenceable,
   private = list(
     xmlElement = "MI_Georeferenceable",
-    xmlNamespacePrefix = "GMI"
+    xmlNamespacePrefix = list(
+      "19139" = "GMI",
+      "19115-3" = "MSR"
+    )
   ),
   public = list(
     
@@ -24,7 +29,7 @@ ISOImageryGeoreferenceable <- R6Class("ISOImageryGeoreferenceable",
     geolocationInformation = list(),
     
     #'@description Initializes object 
-    #'@param xml object of class \link{XMLInternalNode-class}
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     },
@@ -50,4 +55,4 @@ ISOImageryGeoreferenceable <- R6Class("ISOImageryGeoreferenceable",
     }
     
   )                        
-)
\ No newline at end of file
+)
