@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO imagery ProcessStepReport
-#' @return Object of \code{\link{R6Class}} for modelling an ISO imagery ProcessStepReport
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO imagery ProcessStepReport
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'    md <- ISOImageryProcessStepReport$new()
@@ -15,7 +15,9 @@
 #'    xml <- md$encode()
 #' 
 #' @references 
-#'   ISO 19115-2:2009 - Geographic information -- Metadata Part 2: Extensions for imagery and gridded data
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19115/-2/gmi/1.0/gmi/#element_LE_ProcessStepReport}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mrl/2.0/mrl/#element_LE_ProcessStepReport}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #' 
@@ -23,7 +25,10 @@ ISOImageryProcessStepReport <- R6Class("ISOImageryProcessStepReport",
   inherit = ISOAbstractObject,
   private = list(
     xmlElement = "LE_ProcessStepReport",
-    xmlNamespacePrefix = "GMI"
+    xmlNamespacePrefix = list(
+      "19139" = "GMI",
+      "19115-3" = "MRL"
+    )
   ),
   public = list(
   
@@ -35,7 +40,7 @@ ISOImageryProcessStepReport <- R6Class("ISOImageryProcessStepReport",
     fileType = NULL,
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     },
@@ -71,4 +76,4 @@ ISOImageryProcessStepReport <- R6Class("ISOImageryProcessStepReport",
     }
     
   )
-)
\ No newline at end of file
+)
