@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO imagery source
-#' @return Object of \code{\link{R6Class}} for modelling an ISO imagery source
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO imagery source
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'    md <- ISOImagerySource$new()
@@ -18,7 +18,9 @@
 #'    xml <- md$encode()
 #' 
 #' @references 
-#'   ISO 19115-2:2009 - Geographic information -- Metadata Part 2: Extensions for imagery and gridded data
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19115/-2/gmi/1.0/gmi/#element_LE_Source}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mrl/2.0/mrl/#element_LE_Source}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #' 
@@ -26,7 +28,10 @@ ISOImagerySource <- R6Class("ISOImagerySource",
   inherit = ISOAbstractObject,
   private = list(
     xmlElement = "LE_Source",
-    xmlNamespacePrefix = "GMI"
+    xmlNamespacePrefix = list(
+      "19139" = "GMI",
+      "19115-3" =  "MRL"
+    )
   ),
   public = list(
     
@@ -36,7 +41,7 @@ ISOImagerySource <- R6Class("ISOImagerySource",
     resolution = NULL,
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}
     initialize = function(xml = NULL){
       super$initialize(xml = xml)
     },
@@ -64,4 +69,4 @@ ISOImagerySource <- R6Class("ISOImagerySource",
     }
     
   )                        
-)
\ No newline at end of file
+)
