@@ -4,11 +4,13 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO measure length
-#' @return Object of \code{\link{R6Class}} for modelling an ISO Length measure
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO Length measure
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @references
-#'  ISO/TS 19103:2005 Geographic information -- Conceptual schema language
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gco/1.0/gco/#element_Length}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/gco/1.0/gco/#element_Length}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -16,12 +18,15 @@ ISOLength <- R6Class("ISOLength",
     inherit = ISOMeasure,
     private = list(
       xmlElement = "Length",
-      xmlNamespacePrefix = "GCO"
+      xmlNamespacePrefix = list(
+        "19139" = "GCO",
+        "19115-3" = "GCO"
+      )
     ),
     public = list(
       
       #'@description Initializes object
-      #'@param xml object of class \link{XMLInternalNode-class}
+      #'@param xml object of class \link[XML]{XMLInternalNode-class}
       #'@param value value
       #'@param uom uom symbol of unit of measure used
       #'@param useUomURI use uom URI. Default is \code{FALSE}
@@ -34,4 +39,4 @@ ISOLength <- R6Class("ISOLength",
         )
       }
     )                        
-)
\ No newline at end of file
+)
