@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO maintenance information
-#' @return Object of \code{\link{R6Class}} for modelling an ISO MaintenanceInformation
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO MaintenanceInformation
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples 
 #'   md <- ISOMaintenanceInformation$new()
@@ -13,7 +13,9 @@
 #'   xml <- md$encode()
 #'   
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_MD_MaintenanceInformation}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mmi/1.0/mmi/#element_MD_MaintenanceInformation}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -21,14 +23,17 @@ ISOMaintenanceInformation <- R6Class("ISOMaintenanceInformation",
    inherit = ISOAbstractObject,
    private = list(
      xmlElement = "MD_MaintenanceInformation",
-     xmlNamespacePrefix = "GMD"
+     xmlNamespacePrefix = list(
+       "19139" = "GMD",
+       "19115-3" = "MMI"
+     )
    ),
    public = list(
      #'@field maintenanceAndUpdateFrequency maintenanceAndUpdateFrequency
      maintenanceAndUpdateFrequency = NULL,
      
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      initialize = function(xml = NULL){
        super$initialize(xml = xml)
      },
@@ -43,4 +48,4 @@ ISOMaintenanceInformation <- R6Class("ISOMaintenanceInformation",
        self$maintenanceAndUpdateFrequency <- frequency
      }
    )                        
-)
\ No newline at end of file
+)
