@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO pixel orientation
-#' @return Object of \code{\link{R6Class}} for modelling an ISOPixelOrientation
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISOPixelOrientation
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples
 #'   #possible values
@@ -15,7 +15,9 @@
 #'   PixelOrientation <- ISOPixelOrientation$new(value = "center")
 #' 
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_MD_PixelOrientationCode}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/msr/1.0/msr/#element_MD_PixelOrientationCode}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -23,22 +25,24 @@ ISOPixelOrientation <- R6Class("ISOPixelOrientation",
   inherit = ISOCodeListValue,
   private = list(
     xmlElement = "MD_PixelOrientationCode",
-    xmlNamespacePrefix = "GMD"
+    xmlNamespacePrefix = list(
+      "19139" = "GMD",
+      "19115-3" = "MSR"
+    )
   ),
   public = list(
     
     #'@description Initializes object
-    #'@param xml object of class \link{XMLInternalNode-class}  
+    #'@param xml object of class \link[XML]{XMLInternalNode-class}  
     #'@param value value
     #'@param description description
     initialize = function(xml = NULL, value, description = NULL){
       super$initialize(xml = xml, id = private$xmlElement, value = value, description = description,
-                      addCodeSpaceAttr = FALSE)
-      self$attrs <- list()
+                       addCodeListAttrs = FALSE, addCodeSpaceAttr = FALSE)
    }
   )                        
 )
 
 ISOPixelOrientation$values <- function(labels = FALSE){
   return(ISOCodeListValue$values(ISOPixelOrientation, labels))
-}
\ No newline at end of file
+}
