@@ -4,11 +4,13 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO record
-#' @return Object of \code{\link{R6Class}} for modelling an ISORecordType
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISORecordType
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @references
-#'  ISO/TS 19103:2005 Geographic information -- Conceptual schema language
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gco/1.0/gco/#element_RecordType}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/gco/1.0/gco/#element_RecordType}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -16,14 +18,17 @@ ISORecordType <- R6Class("ISORecordType",
    inherit = ISOAbstractObject,
    private = list(
      xmlElement = "RecordType",
-     xmlNamespacePrefix = "GCO"
+     xmlNamespacePrefix = list(
+       "19139" = "GCO",
+       "19115-3" = "GCO"
+     )
    ),
    public = list(
      #'@field value value
      value = NA,
      
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}  
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}  
      #'@param value value
      initialize = function(xml = NULL, value){
        super$initialize(xml = xml)
@@ -32,4 +37,4 @@ ISORecordType <- R6Class("ISORecordType",
        }
      }
    )                        
-)
\ No newline at end of file
+)
