@@ -4,8 +4,8 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO security constraints
-#' @return Object of \code{\link{R6Class}} for modelling an ISO SecurityConstraints
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO SecurityConstraints
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples 
 #'    #create object
@@ -18,7 +18,9 @@
 #'    xml <- md$encode()
 #'    
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_MD_SecurityConstraints}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mco/1.0/mco/#element_MD_SecurityConstraints}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -26,7 +28,10 @@ ISOSecurityConstraints <- R6Class("ISOSecurityConstraints",
    inherit = ISOConstraints,
    private = list(
      xmlElement = "MD_SecurityConstraints",
-     xmlNamespacePrefix = "GMD"
+     xmlNamespacePrefix = list(
+       "19139" = "GMD",
+       "19115-3" = "MCO"
+     )
    ),
    public = list(
      #'@field classification classification: ISOClassification
@@ -39,7 +44,7 @@ ISOSecurityConstraints <- R6Class("ISOSecurityConstraints",
      handlingDescription = NULL,
      
      #'@description Initializes object
-     #'@param xml object of class \link{XMLInternalNode-class}
+     #'@param xml object of class \link[XML]{XMLInternalNode-class}
      initialize = function(xml = NULL){
        super$initialize(xml = xml)
      },
@@ -84,4 +89,4 @@ ISOSecurityConstraints <- R6Class("ISOSecurityConstraints",
        }
      }
    )                                          
-)
\ No newline at end of file
+)
