@@ -4,18 +4,20 @@
 #' @importFrom R6 R6Class
 #' @export
 #' @keywords ISO spatial representation type
-#' @return Object of \code{\link{R6Class}} for modelling an ISO SpatialRepresentationType
-#' @format \code{\link{R6Class}} object.
+#' @return Object of \code{\link[R6]{R6Class}} for modelling an ISO SpatialRepresentationType
+#' @format \code{\link[R6]{R6Class}} object.
 #' 
 #' @examples 
 #'   #possible values
 #'   values <- ISOSpatialRepresentationType$values(labels = TRUE)
 #'   
 #'   #vector example
-#'   vectorRep <- ISORestriction$new(value = "vector")
+#'   vectorRep <- ISOSpatialRepresentationType$new(value = "vector")
 #' 
 #' @references 
-#'   ISO 19115:2003 - Geographic information -- Metadata
+#'   - ISO 19139 \url{https://schemas.isotc211.org/19139/-/gmd/1.0/gmd/#element_MD_SpatialRepresentationTypeCode}
+#'   
+#'   - ISO 19115-3 \url{https://schemas.isotc211.org/19115/-3/mcc/1.0/mcc/#element_MD_SpatialRepresentationTypeCode}
 #' 
 #' @author Emmanuel Blondel <emmanuel.blondel1@@gmail.com>
 #'
@@ -23,12 +25,15 @@ ISOSpatialRepresentationType <- R6Class("ISOSpatialRepresentationType",
    inherit = ISOCodeListValue,
    private = list(
      xmlElement = "MD_SpatialRepresentationTypeCode",
-     xmlNamespacePrefix = "GMD"
+     xmlNamespacePrefix = list(
+        "19139" = "GMD",
+        "19115-3" = "MCC"
+     )
    ),
    public = list(
       
       #'@description Initializes object
-      #'@param xml object of class \link{XMLInternalNode-class}  
+      #'@param xml object of class \link[XML]{XMLInternalNode-class}  
       #'@param value value
       #'@param description description
       initialize = function(xml = NULL, value = NULL, description = NULL){
@@ -40,4 +45,4 @@ ISOSpatialRepresentationType <- R6Class("ISOSpatialRepresentationType",
 
 ISOSpatialRepresentationType$values <- function(labels = FALSE){
   return(ISOCodeListValue$values(ISOSpatialRepresentationType, labels))
-}
\ No newline at end of file
+}
