@@ -27,6 +27,6 @@ test_that("encoding",{
   md2 <- ISOAssociationRole$new(xml = xml)
   xml2 <- md2$encode()
   
-  expect_true(ISOAbstractObject$compare(md, md2))
+  expect_true(ISOAbstractObject$compare(md, md2, "xml"))
   
 })
\ No newline at end of file
