@@ -55,7 +55,7 @@ test_that("encoding",{
   md2 <- ISOBoundAssociationRole$new(xml = xml)
   xml2 <- md2$encode()
   
-  expect_true(ISOAbstractObject$compare(md, md2))
+  expect_true(ISOAbstractObject$compare(md, md2, "xml"))
   
 })
 
@@ -162,6 +162,6 @@ test_that("encoding - i18n",{
   md2 <- ISOBoundAssociationRole$new(xml = xml)
   xml2 <- md2$encode()
   
-  expect_true(ISOAbstractObject$compare(md, md2))
+  expect_true(ISOAbstractObject$compare(md, md2, "xml"))
   
 })
\ No newline at end of file
